autoconfigure

package
v0.1.0-preview.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package autoconfigure contributes Agent event logging only when an application explicitly blank-imports it.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DefaultConfig

func DefaultConfig() agentlogging.Config

DefaultConfig contributes conservative bounded defaults.

func DefaultHealthSource

func DefaultHealthSource(config agentlogging.Config, processor *agentlogging.Processor) daemon.HealthSource

DefaultHealthSource contributes optional fixed-code readiness state.

func DefaultMailbox

func DefaultMailbox(config agentlogging.Config) (*event.BestEffortObserver, error)

DefaultMailbox contributes the sole best-effort Agent logging queue.

func DefaultProcessor

func DefaultProcessor(
	config agentlogging.Config,
	mailbox *event.BestEffortObserver,
	logger *spicelogging.Logger,
) (*agentlogging.Processor, lifecycle.Cleanup, error)

DefaultProcessor contributes the single consumer and generated cleanup.

func SpiceAutoConfiguration

func SpiceAutoConfiguration() starter.AutoConfiguration

SpiceAutoConfiguration is statically decoded and never executed during analysis.

Types

This section is empty.

Jump to